@@ -17,3 +17,5 @@
 from .test_arguments import TestArguments
 from .test_login import TestLogin
 from .test_prometheus import TestPrometheus
+from .test_scrape import TestScrape
+from .test_server import TestServer
